#############
# $Id: create_psuedo_qseq_custom.pm 12698 2011-02-24 14:34:04Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2009-11-03
# Last Changed On: $Date: 2011-02-24 14:34:04 +0000 (Thu, 24 Feb 2011) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/trunk/lib/npg_pipeline/analysis/create_psuedo_qseq_custom.pm $

package npg_pipeline::analysis::create_psuedo_qseq_custom;
use Moose;
use MooseX::InsideOut;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12698 $ =~ /(\d+)/mxs; $r; };
use File::Spec;

extends qw{npg_pipeline::base};
with qw{npg_common::roles::run::path_info};
with qw{npg_common::roles::run::long_info};
with qw{npg_pipeline::roles::business::flag_options};

Readonly::Scalar our $CUSTOM_SUFFIX  => q{_custom.txt};

=head1 NAME

npg_pipeline::analysis::create_psuedo_qseq_custom

=head1 VERSION

$LastChangedRevision: 12698 $

=head1 SYNOPSIS

  my $oPseudoFileMaker = npg_pipeline::analysis::create_psuedo_qseq_custom->new({
    run_folder => $sRunFolder,
    recalibrated_path => $sRecalibratedPath,
    bustard_path => $sBustardPath
  });

=head1 DESCRIPTION

This object module exposes the method run, which, should it be able to work out (or have been provided) the recalibrated path (where it should find
qseq_custom files) and the bustard_path (where the qseq files should have been created), it will check there is a qseq_custom file for each qseq file,
and any which are missing, it will create a softlink in the recalibrated path to the qseq file

npg_common::roles::run::path_info is used in this class, so you can pass through other parameters which will (within the methods exported by the role)
provide the paths to the recalibrated and bustard dirs

=head1 SUBROUTINES/METHODS

=head2 run - method to go through the qseq files in the Bustard directory, and check there is a corresponding qseq_custom file in the GERALD directory
if not, then create a softlink to the file with the qseq_custom name

  eval { $oPseudoFileMaker->run(); } or do { ... Your error handling here ... };

=cut

sub run {
  my ($self) = @_;

  my $non_recalibrated_path = $self->bustard_path();
  my @non_calibrated_qseq_files = $self->_obtain_files( {
    directory  => $non_recalibrated_path,
    file_match => q{qseq.txt},
  } );

  my $recalibrated_path = $self->recalibrated_path();
  my $recalibrated_qseq_location_path = $self->qseq_location_path();

  foreach my $qseq_file ( @non_calibrated_qseq_files ) {
    my ( $root, $file_extension ) = split /[.]/xms, $qseq_file;

    my $link_file = qq{$recalibrated_path/$root} . $CUSTOM_SUFFIX;

    if ( -e $link_file ) {
      $self->log( qq{already found $link_file} );
      next;
    }

    my $link_command = -e qq{$recalibrated_qseq_location_path/$qseq_file} ? qq{ln -s $recalibrated_qseq_location_path/$qseq_file $link_file}
                     :                                                      qq{ln -s $non_recalibrated_path/$qseq_file $link_file}
                     ;


    if ( $self->verbose() ) {
      $self->log( $link_command );
    }

    my $result = qx{$link_command};
    if ( $CHILD_ERROR ) {
      croak qq{unable to run command\n\t$link_command:\n\t$result};
    }

  }

  return 1;
}


# returns an array of filenames from the given directory matching the file_match string
sub _obtain_files {
  my ($self, $arg_refs) = @_;

  my $dh;
  opendir $dh, $arg_refs->{directory} or croak qq{Unable to open $arg_refs->{directory}};
  my @dir_files = readdir $dh;
  closedir $dh;

  my @wanted_files;
  foreach my $file (@dir_files) {
    if ($file =~ /\Q$arg_refs->{file_match}\E/xms) {
      push @wanted_files, $file;
    }
  }

  @wanted_files = sort @wanted_files;
  return @wanted_files;
}



no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item Carp

=item English -no_match_vars

=item Readonly

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
