#############
# $Id: fastqcheck.pm 12453 2011-01-26 10:43:41Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2009-07-10
# Last Changed On: $Date: 2011-01-26 10:43:41 +0000 (Wed, 26 Jan 2011) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/trunk/lib/npg_pipeline/archive/file/generation/fastqcheck.pm $

package npg_pipeline::archive::file::generation::fastqcheck;
use Moose;
use MooseX::InsideOut;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12453 $ =~ /(\d+)/mxs; $r; };
use File::Basename;

extends q{npg_pipeline::archive::file::generation};

sub generate {
  my ($self, $arg_refs) = @_;

  my $id_run = $self->id_run();

  $self->log(qq{Creating Jobs to create fastqcheck files for $id_run});

  if ( $arg_refs->{fastqcheck_by_tag} && $self->is_indexed() ) {
    $self->log( q{************* fastqcheck by tag ************} );
    my @job_ids_by_tag = $self->_generate_fastqcheck_by_tag( $arg_refs );
    return @job_ids_by_tag;
  }

  if ( $arg_refs->{fastqcheck_by_tag} ) {
    $self->log( q{Run is not indexed, so no creation of fastqcheck by tag files} );
    return ();
  }

  $arg_refs->{array_string} = $self->create_array_string( $self->positions( $arg_refs ) );

  my @fast_q_file_names = $self->generate_fastq_and_check_name_parts($arg_refs);

  my @job_ids;

  foreach my $file_name (@fast_q_file_names) {
    $self->log( $file_name );
    $arg_refs->{file_name} = $file_name;
    push @job_ids, $self->submit_bsub_command( $self->_generate_bsub_command( $arg_refs ) );
  }

  return @job_ids;
}

sub _generate_fastqcheck_by_tag {
  my ( $self, $arg_refs ) = @_;

  my @job_ids;

  my @positions = $self->positions( $arg_refs );

  foreach my $position ( @positions ) {
    $self->add_lane_tag_pairs( $position );
  }

  if ( $self->has_no_lane_tag_pairs() ) {
    return @job_ids;
  }

  $arg_refs->{array_string} = $self->lsf_job_array_from_lane_tag_pairs();
  if ( $self->is_paired_read() ) {
    push @job_ids, $self->submit_bsub_command( $self->_generate_bsub_command_by_tag( $arg_refs , 1 ) );
    push @job_ids, $self->submit_bsub_command( $self->_generate_bsub_command_by_tag( $arg_refs , 2 ) );
  } else {
    push @job_ids, $self->submit_bsub_command( $self->_generate_bsub_command_by_tag( $arg_refs , 1 ) );
  }

  return @job_ids;
}

###############
# responsible for generating the bsub command to be executed
sub _generate_bsub_command {
  my ( $self, $arg_refs ) = @_;

  my $file_name = $arg_refs->{file_name};

  my ( $nulla, $nullb, $end ) = split /_/xms, $file_name;

  my $required_job_completion = $arg_refs->{required_job_completion};
  my $timestamp = $self->timestamp();
  my $script_bin = $self->internal_script_bin();
  my $id_run = $self->id_run();

  my $outfile = $self->make_log_dir( $self->archive_path() ) . q{/} . $self->bsub_output_file();
  my $job_name = q{fastqcheck_creation_} . $id_run . q{_};
  if ( $end ) {
    $job_name .= $end . q{_};
  }
  $job_name .= $timestamp;
  my $replacement = $job_name . q{.%I.%J};
  $outfile =~ s/substitute_this/$replacement/xms;
  $job_name .= $arg_refs->{array_string};

  my $fast_q_file = $self->archive_path() . q{/} . $self->fastq_file_constructs();
  $fast_q_file =~ s/substitute_this/$file_name/xms;
  $self->log( $fast_q_file );
  my $fast_qcheck_file = $self->archive_path() . q{/} . $self->fastqcheck_file_constructs();
  $fast_qcheck_file =~ s/substitute_this/$file_name/xms;
  $self->log( $fast_qcheck_file );

  my $job_sub = q{bsub -q } . $self->lsf_queue() . q{ };
  $job_sub .=  ( $self->fs_resource_string( {
    counter_slots_per_job => 1,
  } ) ) . q{ };
  $job_sub .= qq{$required_job_completion -J $job_name -o $outfile '$script_bin/} . $self->external_script_names_conf()->{fast_qcheck_creator_script} . qq{ < $fast_q_file > $fast_qcheck_file'};

  if ($self->verbose()) { $self->log($job_sub); }
  return $job_sub;
}

sub _generate_bsub_command_by_tag {
  my ( $self, $arg_refs, $end ) = @_;

  my $position_string = $self->position_decode_string();
  my $tag_index_string = $self->tag_index_decode_string();

  my $required_job_completion = $arg_refs->{required_job_completion};
  my $timestamp = $self->timestamp();
  my $script_bin = $self->internal_script_bin();
  my $position = $arg_refs->{position};
  my $file_name = $self->archive_path() . q{/lane} . $position_string . q{/} . $self->id_run() . q{_} . $position_string;
  if ( $end ) {
    $file_name .= q{_} . $end;
  }
  $file_name .= q{#} . $tag_index_string . q{.fastq};
#  my ($fastq_name, $dir, $suffix) =  fileparse( $file_name, qw(.fastq) );

  my $outfile = $self->archive_path() . q{/log/} . $self->bsub_output_file();
  my $job_name = q{fastqcheck_creation_} . $self->id_run() . q{_};
  if ( $end ) {
    $job_name .= q{end} . $end . q{_};
  }
  $job_name .= $timestamp;
  my $replacement = $job_name . q{.%I.%J};
  $outfile =~ s/substitute_this/$replacement/xms;
  $job_name .= $arg_refs->{array_string};

  my $fast_qcheck_file = $file_name . q{check};

  my $job_sub = q{bsub -q } . $self->lsf_queue() . q{ };
  $job_sub .=  ( $self->fs_resource_string( {
    counter_slots_per_job => 1,
  } ) ) . q{ };
  $job_sub .= qq{$required_job_completion -J $job_name -o $outfile 'bash; if [ -e $file_name ]; then $script_bin/} . $self->external_script_names_conf()->{fast_qcheck_creator_script} . qq{ < $file_name > $fast_qcheck_file; else echo Fastq file does not exist: $file_name; fi'};

  if ($self->verbose()) { $self->log($job_sub); }
  return $job_sub;
}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 NAME

npg_pipeline::archive::file::generation::fastqcheck

=head1 VERSION

$LastChangedRevision: 12453 $

=head1 SYNOPSIS

  my $oAfgfqcheck = npg_pipeline::archive::file::generation::fastqcheck->new({
    run_folder => $sRunFolder,
  });

=head1 DESCRIPTION

Object module which knows how to construct and submits the command line to LSF for creating fastqcheck files.

=head1 SUBROUTINES/METHODS

=head2 generate - generates the bsub jobs and submits them for creating the fastqcheck files, returning an array of job_ids.

  my @job_ids = $oAfgfqcheck->generate({
    required_job_completion} => q{-w (123 && 321)};
    timestamp                => q{20090709-123456};
    solexa_bin               => q{/software/solexa/bin};
    id_run                   => 1234;
    BSUB_ERROR_FILE          => q{substitute_this.err};
    BSUB_OUTPUT_FILE         => q{substitute_this.out};
  });

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Carp

=item English -no_match_vars

=item Readonly

=item Moose

=item npg_pipeline::archive::file::generation

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
