#############
# $Id: WebCache.pm 11652 2010-11-08 11:38:52Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 
# Last Changed On: $Date: 2010-11-08 11:38:52 +0000 (Mon, 08 Nov 2010) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/trunk/lib/npg_pipeline/archive/folder/WebCache.pm $

package npg_pipeline::archive::folder::WebCache;
use Moose;
use MooseX::InsideOut;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 11652 $ =~ /(\d+)/mxs; $r; };
use Cwd;

extends qw{npg_pipeline::archive};

Readonly::Scalar our $WEBCACHE_LINK_NAME => q{webcache};

=head1 NAME

npg_pipeline::archive::folder::WebCache

=head1 VERSION

$LastChangedRevision: 11652 $

=head1 SYNOPSIS

  use npg_pipeline::archive::folder::WebCache;
  my $oWebCache = npg_pipeline::archive::folder::WebCache->new( {
    id_run => $iIdRun,
  } );

=head1 DESCRIPTION

This module is set just to create a relative symlink to the webcache directory used in the archive directory

=head1 SUBROUTINES/METHODS

=head2 create_webcache_link

Does exactly what it says on the tin ( in the archive directory ).

  $oWebCache->create_webcache_link();

This will just run. No bsub jobs will be created.

=cut

sub create_webcache_link {
  my ( $self, @args ) = @_;

  my $cache = $ENV{NPG_WEBSERVICE_CACHE_DIR};

  # if there is no cache, or the folder doesn't exist, then nothing to softlink
  if ( ! $cache || ! -d $cache ) {
    $self->log( q{no symlink created, since no cache dir found} );
    return ()
  }

  # if the softlink isn't in the runfolder path, then it isn't for softlinking
  my $runfolder_path = $self->runfolder_path();
  if ( $cache !~ /\A$runfolder_path/xms ) {
    $self->log( q{webcache is not in the runfolder, so no symlink will be created} );
    return ();
  }

  my @temp = split m{/}xms, $cache;
  $cache = pop @temp;

  my $archive_path = $self->archive_path();
  # ensure that the archive path exists
  $self->make_log_dir( $archive_path );

  # change to the archive directory, and create the softlink
  eval {
    my $cwd = getcwd();
    chdir $archive_path or croak qq{could not cd to $archive_path};
    qx{ln -s ../../../../../$cache $WEBCACHE_LINK_NAME};
    if ( $CHILD_ERROR ) {
      croak q{unable to softlink the cache directory into the archive directory};
    }
    chdir $cwd or croak qq{could not cd to $cwd};
  } or do {
    croak $EVAL_ERROR;
  };

  return ();
}

=head2 webcache_directory_link

returns a string containing the webcache_directory in the archive directory, or undef

  my $sWebCacheDirectory = $oWebCache->webcache_directory_link();

=cut

sub webcache_directory_link {
  my ( $self ) = @_;

  # if the program name is not npg_pipeline_post_qc_review, then return undef, as we don't want it
  # to pick up unexpected webcaches if we are rerunning the analysis
  if ( $PROGRAM_NAME !~ /npg_pipeline_post_qc_review/ixms ) {
    return;
  }

  my $linked_cache;
  eval {
    $self->archive_path();
    $linked_cache = $self->archive_path() . q{/} . $WEBCACHE_LINK_NAME;
    if ( -d $linked_cache ) {
    } else {
      $self->log( q{no softlinked webcache found in archive directory} );
      $linked_cache = undef;
    }
    1;
  } or do {};

  return $linked_cache;
}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item Carp

=item English -no_match_vars

=item Readonly

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
