#############
# $Id: references_adapters.pm 12135 2010-12-10 10:56:10Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2010-08-26
# Last Changed On: $Date: 2010-12-10 10:56:10 +0000 (Fri, 10 Dec 2010) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/trunk/lib/npg_pipeline/pre_exec/references_adapters.pm $

package npg_pipeline::pre_exec::references_adapters;
use Moose;
use MooseX::InsideOut;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12135 $ =~ /(\d+)/mxs; $r; };

extends q{npg_pipeline::base};

with qw{
  npg_pipeline::roles::business::pre_exec_strings
  npg_common::sequence::reference::roles::list
};

=head1 NAME

npg_pipeline::pre_exec::references_adapters

=head1 VERSION

$LastChangedRevision: 12135 $

=head1 SYNOPSIS

  my $ref_adapters = npg_pipeline:;pre_exec::references_adapters->new();
  $ref_adapters->check_existence();

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 check_existence

This is the only method, and it checks that the references and adapters repositories can be found.
If they can't, then the method croaks.

=cut

sub check_existence {
  my ( $self ) = @_;

  my $adapt_repo;

  eval {
    # This does a check on the reference repository by default
    $adapt_repo = $self->ref_repository();
  } or do {
    croak q{Unable to find reference repository } . $adapt_repo . qq{\n\t} . $EVAL_ERROR;
  };

  # now check the adapter directory, which should be parallel to the reference repository
  $adapt_repo =~ s/references/adapters/xms;
  if ( ! -d $adapt_repo ) {
    croak q{Unable to find adapters repository } . $adapt_repo . qq{\n\t} . $EVAL_ERROR;
  }

  return 1;
}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item Carp

=item English -no_match_vars

=item Readonly

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
