#############
# $Id: source_files.pm 12135 2010-12-10 10:56:10Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2009-11-04
# Last Changed On: $Date: 2010-12-10 10:56:10 +0000 (Fri, 10 Dec 2010) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/trunk/lib/npg_pipeline/roles/business/source_files.pm $

package npg_pipeline::roles::business::source_files;
use Moose::Role;

use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12135 $ =~ /(\d+)/mxs; $r; };


# if you add more scalars and method/attributes, add the method/attribute to this array below
Readonly::Scalar our $ALL_SOURCE => [qw{
    oracle lsf
  }];

=head1 NAME

npg_pipeline::roles::business::source_files

=head1 VERSION

$LastChangedRevision: 12135 $

=head1 SYNOPSIS

  package MyPackage;
  use Moose;
  ...
  with qw{npg_pipeline::roles::business::source_files};

=head1 DESCRIPTION

A centralised role to expose the files that may be needed to be sourced to provide environment variables

=head1 SUBROUTINES/METHODS

=head2 all_source_files_as_a_source_string - returns a string 'source /my/first/source/file ; source /my/second/source/file ; .... ;' of all the source files in the role

  my $sAllSourceString = $class->all_source_files_as_a_source_string();

=cut

sub all_source_files_as_a_source_string {
  my ($self) = @_;

  my $source_string = q{};
  foreach my $source_type (@{$ALL_SOURCE}) {
    my $test_bin = $ENV{TEST_BIN} || q{};
    my $value = $self->$source_type();
    if ($value) { # allows for some attributes to be added without defaults to build
      $source_string .= q{source } . $test_bin . $value . q{ ; };
    }
  }

  return $source_string;
}

=head2 oracle - the source file for oracle, defaults to value for oracle in source_files.ini

  my $sOracleSource = $class->oracle();

=cut

has q{oracle} => (isa => q{Str}, is => q{ro}, lazy_build => 1,
                  documentation => q{oracle source file},);

sub _build_oracle {
  my ($self) = @_;
  return $self->source_files_conf()->{oracle_home} . q{/} . $self->source_files_conf()->{oracle};
}

=head2 lsf - the source file for lsf, defaults to value for lsf in source_files.ini

  my $sLSFSource = $class->lsf();

=cut

has q{lsf} => (isa => q{Str}, is => q{ro}, lazy_build => 1,
               documentation => q{lsf source file},);

sub _build_lsf {
  my ($self) = @_;
  return $self->source_files_conf()->{lsf};
}



1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose::Role

=item Carp

=item English -no_match_vars

=item Readonly

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
