# $Id: 10-pluggable_harold_post_qseq.t 12579 2011-02-11 11:58:15Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 14;
use Test::Deep;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use File::Slurp;

my $util = t::util->new();
$util->catch_email();
my $conf_path= $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{OWNING_GROUP} = q{staff};

use_ok('npg_pipeline::pluggable::harold::post_qseq');

my $analysis_runfolder_path = $util->analysis_runfolder_path();
my $analysis_path = q{Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto};

$ENV{TEST_USERAGENT} = $analysis_runfolder_path . q{/useragent};

{
  my $post_qseq;
  my $functions_in_order = [qw(
      create_archive_directory
      create_fastq
      create_fastqcheck
      create_md5
      finish
    )];
  lives_ok {
    $post_qseq = npg_pipeline::pluggable::harold::post_qseq->new({
      schema => q{harold_post_qseq},
      id_run => 1234,
      function_order => $functions_in_order,
      run_folder => q{123456_IL2_1234},
      analysis_path => $analysis_path,
      runfolder_path => $analysis_runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak on creation};
  isa_ok($post_qseq, q{npg_pipeline::pluggable::harold::post_qseq}, q{$post_qseq});
  is($post_qseq->function_order(), $functions_in_order, q{$post_qseq->function_order() set on creation});

  $util->set_staging_analysis_area({with_latest_summary => 1});
#  `ln -s Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto /tmp/staging/IL2/analysis/123456_IL2_1234/Latest_Summary`;
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  lives_ok {
    $post_qseq->main();
  } q{no croak running post_qseq->main()};

}
{
  my $post_qseq;
  lives_ok {
    $post_qseq = npg_pipeline::pluggable::harold::post_qseq->new({
      schema => q{harold_post_qseq},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak on new creation};
  my @function_order;
  lives_ok {
    @function_order = @{$post_qseq->_function_order()};
  } q{no croak obtaining base function order};

  $post_qseq->_clear_function_order;

  $post_qseq->precreated_function_order(q{spam});
  lives_ok {
    @function_order = @{$post_qseq->_function_order()};
  } q{no croak obtaining base function order};
}

{
  my $post_qseq;
  $util->set_staging_analysis_area();
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  my $function_order = [qw{
    set_run_status_secondary_analysis_in_progress
    create_summary_link_analysis
    create_archive_directory
    correct_qseq_for_index_runs
    create_fastq
    create_fastqcheck
    correct_qseq_for_index_runs
    create_md5
    split_nonconsented_sequence
    qc_qX_yield
    set_run_status_qc_review_pending
    finish
  }];
  lives_ok {
    $post_qseq = npg_pipeline::pluggable::harold::post_qseq->new({
      schema => q{harold},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      function_order => $function_order,
      analysis_path => $analysis_path,
      runfolder_path => $analysis_runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak on new creation};

  lives_ok {
    $post_qseq->main();
  } q{no croak running post_qseq->main()};

}

{
  my $post_qseq;
  $util->set_staging_analysis_area();
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  my $function_order = [qw{
    create_summary_link_analysis
    create_archive_directory
    munge_summary_for_multiplex
    set_run_status_secondary_analysis_in_progress
    create_psuedo_qseq_custom
    create_webcache_softlink
    fix_qseq_run_id
    correct_qseq_for_index_runs
    create_fastq
    create_fastqcheck
    create_md5
    split_nonconsented_sequence
    qc_qX_yield
    qc_adapter
    qc_insert_size
    create_schema_information
    bam_generation
    set_run_status_analysis_complete
    set_run_status_qc_review_pending
    finish
  }];
  lives_ok {
    $post_qseq = npg_pipeline::pluggable::harold::post_qseq->new({
      schema => q{harold},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      function_order => $function_order,
      lane => 4,
      analysis_path => $analysis_path,
      runfolder_path => $analysis_runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
      no_bsub => 1,
    });
  } q{no croak on new creation};

  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.htm $analysis_runfolder_path/$analysis_path/Summary.htm];
  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.xml $analysis_runfolder_path/$analysis_path/Summary.xml];
  qx[cp t/data/summary_files/Summary.xsl $analysis_runfolder_path/$analysis_path/Summary.xsl];

  lives_ok {
    $post_qseq->main();
  } q{no croak running post_qseq->main()};

}

{
  my $post_qseq;
  $util->set_staging_analysis_area();
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  my $function_order = [qw{
    create_summary_link_analysis
    create_archive_directory
    munge_summary_for_multiplex
    set_run_status_secondary_analysis_in_progress
    create_psuedo_qseq_custom
    create_webcache_softlink
    fix_qseq_run_id
    correct_qseq_for_index_runs
    create_fastq
    qc_sequence_error4spiked_phix
    finish
  }];
  lives_ok {
    $post_qseq = npg_pipeline::pluggable::harold::post_qseq->new({
      schema => q{harold},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      function_order => $function_order,
      lane => 4,
      analysis_path => $analysis_path,
      runfolder_path => $analysis_runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
      no_bsub => 1,
    });
  } q{no croak on new creation};

  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.htm $analysis_runfolder_path/$analysis_path/Summary.htm];
  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.xml $analysis_runfolder_path/$analysis_path/Summary.xml];
  qx[cp t/data/summary_files/Summary.xsl $analysis_runfolder_path/$analysis_path/Summary.xsl];

  lives_ok {
    $post_qseq->main();
  } q{no croak running post_qseq->main() with qc_sequence_error4split_phix that should do nothing};
}

1;
