# $Id: 20-archive-fastqcheck.t 12453 2011-01-26 10:43:41Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 10;
use Test::Exception;
use lib qw{t};
use t::util;

BEGIN {
  use_ok(q{npg_pipeline::archive::qc::fastqcheck_loader});
}
my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_API_UTIL} = $util->apiutil();
$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
{

  $util->create_multiplex_analysis( { qc_dir => [1..7], } );

  my $fq_loader;
  lives_ok {
    $fq_loader = npg_pipeline::archive::qc::fastqcheck_loader->new({
      run_folder => q{123456_IL2_1234},
      timestamp => q{20090709-123456},
      verbose => 0,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{fq_loader created ok};
  isa_ok( $fq_loader, q{npg_pipeline::archive::qc::fastqcheck_loader}, q{$fq_loader} );

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my @jids;
  lives_ok { @jids = $fq_loader->submit_to_lsf($arg_refs); } q{no croak submitting job to lsf};

  is( scalar @jids, 1, q{1 job id returned} );

  my $command = $util->drop_temp_part_from_paths( $fq_loader->_generate_bsub_command($arg_refs) );
  my $expected_cmd = q{bsub -q test -w'done(123) && done(321)' -J fqcheck_loader_1234_20090709-123456 -R 'rusage[nfs_12=1]' -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/fqcheck_loader_1234_20090709-123456.out 't/bin/software/solexa/bin/fqcheck_loader --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane1 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane2 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane3 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane4 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane5 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane6 --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane7'};
  is( $command, $expected_cmd, q{generated bsub command is correct} );
}
{
  $util->create_analysis( { qc_dir => 1, } );

  my $fq_loader;
  lives_ok {
    $fq_loader = npg_pipeline::archive::qc::fastqcheck_loader->new({
      run_folder => q{123456_IL2_1234},
      timestamp => q{20090709-123456},
      verbose => 0,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{fq_loader created ok};

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my @jids;
  lives_ok { @jids = $fq_loader->submit_to_lsf($arg_refs); } q{no croak submitting job to lsf};

  is( scalar @jids, 1, q{1 job id returned} );

  my $command = $util->drop_temp_part_from_paths( $fq_loader->_generate_bsub_command($arg_refs) );
  my $expected_cmd = q{bsub -q test -w'done(123) && done(321)' -J fqcheck_loader_1234_20090709-123456 -R 'rusage[nfs_12=1]' -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/fqcheck_loader_1234_20090709-123456.out 't/bin/software/solexa/bin/fqcheck_loader --path=/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive'};
  is( $command, $expected_cmd, q{generated bsub command is correct} );
}

1;