# $Id: 20-archive_file_generation-bam_markduplicate.t 12453 2011-01-26 10:43:41Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 16;
use Test::Exception;
use lib qw{t};
use t::util;
use File::Temp qw/ tempfile tempdir /;

use_ok('npg_pipeline::archive::file::generation::bam_markduplicate');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();

$ENV{TEST_RUN_OBJECT} = npg::api::run->new({
    util => $util->apiutil(),
    id_run => 1234,
  });

{
  $util->create_analysis({no_touch_files => 1});


  my $bam_generator;

  lives_ok { $bam_generator = npg_pipeline::archive::file::generation::bam_markduplicate->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 0,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{no croak creating $bam_generator object};
  isa_ok($bam_generator, q{npg_pipeline::archive::file::generation::bam_markduplicate}, q{$bam_generator});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my $hex;
  my $md5_object = Digest::MD5->new();
  my @bsub_commands = $bam_generator->_generate_bsub_commands({
      positions => [1,2,3,6,7,8],
      multiplex => 0,
      split_nc => 1,
      arg_refs => $arg_refs,
  });
  is( scalar @bsub_commands, 2, q{2 bsub commands returned} );
  my $bsub_command = $util->drop_temp_part_from_paths( $bsub_commands[0] );
  my $expected_command = q{bsub -q test -R 'select[mem>4000] rusage[mem=4000,nfs_12=1]' -M4000000 -w'done(123) && done(321)' -J 'bam_mark_duplicate.pl_1234_20090709-123456[1-3,6-8]%64' -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/bam_mark_duplicate.pl_1234_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/bam_mark_duplicate.pl --replace_file 1 --id_run 1234 --position `echo $LSB_JOBINDEX` --input_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_human.bam --output_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_human_mk.bam --metrics_json /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc/1234_`echo $LSB_JOBINDEX`_human_bam_flagstats.json --human_split human'};
  is( $bsub_command, $expected_command, q{first generated bsub command is correct} );
  $bsub_command = $util->drop_temp_part_from_paths( $bsub_commands[1] );
  $expected_command = q{bsub -q test -R 'select[mem>4000] rusage[mem=4000,nfs_12=1]' -M4000000 -w'done(123) && done(321)' -J 'bam_mark_duplicate.pl_1234_20090709-123456[1-3,6-8]%64' -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/bam_mark_duplicate.pl_1234_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/bam_mark_duplicate.pl --replace_file 1 --id_run 1234 --position `echo $LSB_JOBINDEX` --input_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_nonhuman.bam --output_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_nonhuman_mk.bam --metrics_json /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc/1234_`echo $LSB_JOBINDEX`_nonhuman_bam_flagstats.json --human_split nonhuman'};
  is( $bsub_command, $expected_command, q{second generated bsub command is correct} );

  @bsub_commands = $bam_generator->_generate_bsub_commands({
      positions => [1,2,3,5,6,7],
      multiplex => 0,
      split_nc  => 0,
      spiked_phix => 1,
      arg_refs => $arg_refs,
  });
  is( scalar @bsub_commands, 1, q{1 bsub commands returned for mark phix bam file} );
  $bsub_command = $util->drop_temp_part_from_paths( $bsub_commands[0] );
  $expected_command = q{bsub -q test -R 'select[mem>4000] rusage[mem=4000,nfs_12=1]' -M4000000 -w'done(123) && done(321)' -J 'bam_mark_duplicate.pl_1234_20090709-123456[1-3,5-7]%64' -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/bam_mark_duplicate.pl_1234_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/bam_mark_duplicate.pl --replace_file 1 --id_run 1234 --position `echo $LSB_JOBINDEX` --input_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_phix.bam --output_bam /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`_phix_mk.bam --metrics_json /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc/1234_`echo $LSB_JOBINDEX`_phix_bam_flagstats.json --human_split phix'};
  is( $bsub_command, $expected_command, q{first generated bsub phix command is correct} );

  $ENV{TEST_API_UTIL} = $util->apiutil();
  
  my @jids;
  lives_ok { @jids = $bam_generator->generate($arg_refs); } q{no croak running generate};
  is(scalar@jids, 4, q{4 job ids returned});
}

{ 
  $util->create_multiplex_analysis();
  my $generator;

  lives_ok { $generator = npg_pipeline::archive::file::generation::bam_markduplicate->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 0,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{no croak creating $generator object};
  isa_ok($generator, q{npg_pipeline::archive::file::generation::bam_markduplicate}, q{$generator});
  my $dir = $generator->archive_path();
  my $runfolder = $generator->runfolder_path();
  mkdir "$dir/lane7";
  `cp t/data/tag_files/lane_7.tag $runfolder`;
  mkdir "$dir/lane8";
  `touch $runfolder/lane_8.tag`;
  my $arg_refs = {};
  $arg_refs->{required_job_completion}  = q{-w'done(123) && done(321)'};
  my @jids;
  lives_ok { @jids = $generator->generate($arg_refs); } q{no croak running generate};
  is(scalar@jids, 6, q{6 job ids returned});
  `cp t/data/tag_files/lane_7.tag $runfolder/lane_1.tag`;
  lives_ok { @jids = $generator->generate($arg_refs); } q{no croak running generate};
  is(scalar@jids, 7, q{7 job ids returned});
}
1;
