# $Id: 25-analysis-create_psuedo_qseq_custom.t 12698 2011-02-24 14:34:04Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 6;
use Test::Exception;
use lib qw{t};
use t::util;

BEGIN {
  use_ok(q{npg_pipeline::analysis::create_psuedo_qseq_custom});
}

my $util = t::util->new();
my $conf_path = $util->conf_path();

my $temp_dir = $util->temp_directory();

my $runfolder_path = $util->analysis_runfolder_path();
my $bustard_home   = qq{$runfolder_path/Data/Intensities};
my $bustard_rta    = qq{$bustard_home/Bustard_RTA};
my $gerald_rta     = qq{$bustard_rta/GERALD_RTA};

sub set_staging_analysis_area {
  my ($indexed) = @_;

  `rm -rf $temp_dir/staging`;
  `mkdir -p $runfolder_path/Config`;
  `mkdir -p $gerald_rta`;
  `touch $bustard_rta/s_1_1_001_qseq.txt`;
  `touch $bustard_rta/s_1_2_001_qseq.txt`;
  `touch $bustard_rta/s_2_1_001_qseq.txt`;
  `touch $bustard_rta/s_2_2_001_qseq.txt`;
  `touch $gerald_rta/s_1_1_001_qseq_custom.txt`;
  `touch $gerald_rta/s_1_2_001_qseq_custom.txt`;

  if ($indexed) {
    `cp t/data/Recipes/Recipe_GA2-PEM_MP_2x76Cycle+8_v7.7.xml $runfolder_path/`;
    `cp t/data/mock_qseqs/1234/s_8_2_0001_qseq.txt $bustard_rta/s_1_t_001_qseq.txt`;
    `touch $bustard_rta/s_2_t_001_qseq.txt`;
  } else {
    `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $runfolder_path/`;
  }

  `cp t/data/Recipes/TileLayout.xml $runfolder_path/Config/`;

  return 1;
}

sub strip_preset_custom_qseqs {
  `rm -f $gerald_rta/s_1_1_001_qseq_custom.txt`;
  `rm -f $gerald_rta/s_1_2_001_qseq_custom.txt`;
  return 1;
}

{
  set_staging_analysis_area();
  my $object;
  lives_ok { $object = npg_pipeline::analysis::create_psuedo_qseq_custom->new({
    id_run => 1234,
    run_folder => q{123456_Il2_1234},
    runfolder_path => $runfolder_path,
    bustard_path => $bustard_rta,
    recalibrated_path => $gerald_rta,
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{object creation ok};
  isa_ok($object, q{npg_pipeline::analysis::create_psuedo_qseq_custom}, q{$object});

  lives_ok { $object->run(); } q{run is ok - returns quickly since there are qseq_custom files found};

  strip_preset_custom_qseqs();

  lives_ok { $object->run(); } q{run is ok};
}
{
  set_staging_analysis_area(1);
  my $object = npg_pipeline::analysis::create_psuedo_qseq_custom->new({
    id_run => 1234,
    run_folder => q{123456_Il2_1234},
    runfolder_path => $runfolder_path,
    bustard_path => $bustard_rta,
    recalibrated_path => $gerald_rta,
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
    is_indexed => 1,
  });
  strip_preset_custom_qseqs();

  `mkdir -p $gerald_rta/Temp/Custom`;
  `touch $gerald_rta/Temp/Custom/s_3_1_001_qseq.txt`;
  `touch $gerald_rta/Temp/Custom/s_2_1_001_qseq.txt`;
  `cp t/data/mock_qseqs/1234/s_8_3_0001_qseq.txt $gerald_rta/Temp/Custom/s_2_3_001_qseq.txt`;
  `cp t/data/mock_qseqs/1234/s_8_3_0001_qseq.txt $gerald_rta/Temp/Custom/s_3_3_001_qseq.txt`;
  `cp t/data/mock_qseqs/1234/s_8_2_0001_qseq.txt $bustard_rta/s_2_2_001_qseq.txt`;
  `cp t/data/mock_qseqs/1234/s_8_2_0001_qseq.txt $bustard_rta/s_3_2_001_qseq.txt`;
   

  lives_ok { $object->run(); } q{run is ok};
}
1;