# $Id: 25-harold_calibration.t 12698 2011-02-24 14:34:04Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 46;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use t::useragent;
use DateTime;
use Test::MockObject;
use Cwd;
use File::Slurp;

my $ua = t::useragent->new({ is_success => 1 });
my $util = t::util->new({
  useragent => $ua,
});
$util->catch_email();

my $curdir = getcwd();

$ENV{TEST_API_UTIL} = $util->apiutil();
$ENV{TEST_BIN} = $curdir . q{/t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};
$ENV{NPG_WEBSERVICE_CACHE_DIR} = $curdir . q{/t/data};

my ($mock_ref_finder, $id_run, $position, $refs, $single_ref_found);

BEGIN {
  $mock_ref_finder = Test::MockObject->new();
  $mock_ref_finder->set_bound( q{position}, \$position );
  $mock_ref_finder->set_bound( q{id_run}, \$id_run );
  $mock_ref_finder->set_bound( q{refs}, \$refs );
  $mock_ref_finder->set_bound( q{single_ref_found}, \$single_ref_found );
  $mock_ref_finder->fake_module( qw{npg_common::sequence::reference} );
  $mock_ref_finder->fake_new( qw{npg_common::sequence::reference} );
  
  use_ok(q{npg_pipeline::analysis::harold_calibration});
}

my $conf_path = $util->conf_path();

my $runfolder_path = $util->analysis_runfolder_path();
my $bustard_home   = qq{$runfolder_path/Data/Intensities};
my $bustard_rta    = qq{$bustard_home/Bustard_RTA};
my $gerald_rta     = qq{$bustard_rta/GERALD_RTA};
my $config_path    = qq{$runfolder_path/Config};

$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

sub set_staging_analysis_area {
  `rm -rf /tmp/staging`;
  `mkdir -p $bustard_rta`;
  `mkdir $config_path`;
  `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $runfolder_path/`;
  `cp t/data/Recipes/TileLayout.xml $config_path/`;
  return 1;
}

{
  set_staging_analysis_area();
  my $harold;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      no_eland => 1,
      no_control_lane => 1,
      conf_path => $conf_path,
      domain => q{test},
      log_file_path => $runfolder_path,
      log_file_name => q{npg_pipeline_pb_cal_20091028-101635.log},
      instrument_model => q{HK},
    });
  } q{create $harold object ok};
  isa_ok($harold, q{npg_pipeline::analysis::harold_calibration}, q{$harold});
  my @job_ids = $harold->generate_calibration_table({});
  is( scalar @job_ids, 0, q{no job ids as no_eland and no_control_lane set} );
  is( $harold->find_bustard(), $bustard_rta, q{bustard dir found ok} );

  @job_ids = $harold->generate_recalibrated_qseqs({});
  is( scalar @job_ids, 0, q{no job ids as no_eland and no_control_lane set} );
  is( $harold->find_bustard(), $bustard_rta, q{bustard dir found ok} );

  is( $harold->calibration_table_name( { id_run => 1234, read => 2 } ),  q{}, q{generated calibration table name is empty string});

  is( $util->drop_temp_part_from_paths( $harold->_post_qseq_cmd({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  }) ), q{bsub -q test  -R 'rusage[nfs_12=1]' -o '/staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal/log/post_qseq_1234_20091028-101635-%J.out' -J post_qseq_1234_20091028-101635 't/bin/software/solexa/bin/npg_pipeline_post_qseq --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --id_run 1234 --instrument_model HK --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --lsf_queue test --no_control_lane  --no_eland  --pb_cal_log_file /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_pb_cal_20091028-101635.log --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234'},
  q{generated post_qseq bsub command is correct} );

  is( $util->drop_temp_part_from_paths( $harold->_post_qseq_cmd({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  }) ), q{bsub -q test  -R 'rusage[nfs_12=1]' -o '/staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal/log/post_qseq_1234_20091028-101635-%J.out' -J post_qseq_1234_20091028-101635 't/bin/software/solexa/bin/npg_pipeline_post_qseq --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --fs_resource nfs_12 --id_run 1234 --instrument_model HK --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --internal_script_bin t/bin/software/solexa/bin --lsf_queue test --no_control_lane  --no_eland  --pb_cal_log_file /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_pb_cal_20091028-101635.log --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --post_qseq_executable t/bin/software/solexa/bin/npg_pipeline_post_qseq --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234'},
  q{generated post_qseq bsub command is correct} );

  @job_ids = $harold->submit_post_qseq({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  });
  is( scalar @job_ids, 1, q{1 job id returned from submit_post_qseq} );

  is( $util->drop_temp_part_from_paths( $harold->_pb_cal_command( {
    required_job_dependencies => q{-w'done(123) & done(321)'},
  } ) ), q{bsub -q test  -J npg_pipeline_PB_cal_1234_20091028-101635 -R 'rusage[nfs_12=1]' -o /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_PB_cal_1234_20091028-101635.out 'npg_pipeline_PB_cal --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --fs_resource nfs_12 --id_run 1234 --instrument_model HK --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --internal_script_bin t/bin/software/solexa/bin --lsf_queue test --no_control_lane  --no_eland  --post_qseq_executable t/bin/software/solexa/bin/npg_pipeline_post_qseq --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234 --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635 --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635 --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635/PB_cal --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635/PB_cal'},
  q{generated pb_cal bsub command is correct} );

  is( $util->drop_temp_part_from_paths( $harold->_pb_cal_command( {
    required_job_dependencies => q{-w'done(123) & done(321)'},
    only_basecall => 1,
  } ) ), q{bsub -q test  -J npg_pipeline_PB_cal_1234_20091028-101635 -R 'rusage[nfs_12=1]' -o /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_PB_cal_1234_20091028-101635.out 'npg_pipeline_PB_cal --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --fs_resource nfs_12 --id_run 1234 --instrument_model HK --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --internal_script_bin t/bin/software/solexa/bin --lsf_queue test --no_control_lane  --no_eland  --post_qseq_executable t/bin/software/solexa/bin/npg_pipeline_post_qseq --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234 --no_recalibration  --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635 --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635 --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635/no_cal --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/PB_basecalls_20091028-101635/no_cal'},
  q{generated pb_cal bsub command for only basecall is correct} );

}

{
  set_staging_analysis_area();
  my $harold;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      verbose => 1,
      conf_path => $conf_path,
      domain => q{test},
      ref_repository => $curdir . q{/t/data/sequence/references},
      instrument_model => q{HK},
    });
  } q{create $harold object ok};

  my $req_job_completion = q{-w'done(123) && done(321)'};
  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  my @job_ids = $harold->launch_pb_cal({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  });
  is( scalar @job_ids, 1, q{1 job id returned from submit_post_qseq} );

  my $job = qq{bsub -q test -E 't/bin/software/solexa/bin/npg_pipeline_preexec_references --ref_repository $curdir/t/data/sequence/references' -o log/PB_cal_table_1234_4_20091028-101635.out -J PB_cal_table_1234_4_20091028-101635 -C 99999999 -R 'select[mem>3072] rusage[mem=3072,nfs_12=1] span[hosts=1]' -M 3072000 -w'done(123) && done(321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_calibration --runfolder_dir $runfolder_path --bustard_dir $bustard_rta --run 1234 --lane 4 --t_filter 2 --read 1 --cstart 1 --prefix 1234_4_1 --mode 2 --bam 1234_4.bam "};

  lives_ok {
    @job_ids = $harold->generate_calibration_table( $arg_refs );
  } q{no croak submitting calibration table jobs};
  is( scalar @job_ids, 2, q{2 jobs created});
  note $job_ids[0];

  is( $harold->_calibration_table_bsub_command( {
   dir => $bustard_rta,
   position => 4,
   read => 1,
   job_dependencies => $req_job_completion,
   ref_seq => q{phix-illumina.fa},
   control => 1,
  } ), $job, q{generated bsub command is correct} );

  my $cal_table = q{1234_4_2_train_purity_caltable.txt};
  is( $harold->calibration_table_name( { id_run => 1234, read => 2, mode => 2 } ), $cal_table, q{generated calibration table name is correct});
  $job = qq{bsub -q test -o log/PB_cal_score_1234_3_20091028-101635.out -J PB_cal_score_1234_3_20091028-101635 -C 99999999 -R 'select[mem>1725] rusage[mem=1725,nfs_12=1] span[hosts=1]' -M 1725000 -w'done(123) && done(321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_predictor --runfolder_dir $runfolder_path --bustard_dir $bustard_rta --run 1234 --lane 3 --read 1 --ct 1234_4_2_train_purity_caltable.txt --cstart 1 "};
  is( $harold->_recalibration_bsub_command( {
    dir => $bustard_rta,
    position => 3,
    read => 1,
    job_dependencies => $req_job_completion,
    calibration_table => $cal_table,
  } ), $job, q{generated bsub command for recalibration job is correct});

  lives_ok {
    @job_ids = $harold->generate_recalibrated_qseqs($arg_refs);
  } q{no croak submitting recalibration jobs};
  is( scalar @job_ids, 8, q{8 jobs created});

}

{
  set_staging_analysis_area();
  my $harold;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      verbose => 1,
      preferred_control_lane => 4,
      conf_path => $conf_path,
      domain => q{test},
      ref_repository => $curdir . q{/t/data/sequence/references},
#      instrument_model => q{HK},
    });
  } q{create $harold object ok};

  my $req_job_completion = q{-w'done(123) && done(321)'};
  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  $ENV{TEST_RUN_OBJECT} = npg::api::run->new({
    util   => $util->apiutil(),
    id_run => 1234,
  });

  my @job_ids = $harold->launch_pb_cal({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  });
  is( scalar @job_ids, 1, q{1 job id returned from submit_post_qseq} );

  my $job = qq{bsub -q test -E 't/bin/software/solexa/bin/npg_pipeline_preexec_references --ref_repository $curdir/t/data/sequence/references' -o log/PB_cal_table_1234_4_20091028-101635.out -J PB_cal_table_1234_4_20091028-101635 -C 99999999 -R 'select[mem>3072] rusage[mem=3072,nfs_12=1] span[hosts=1]' -M 3072000 -w'done(123) && done(321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_calibration --runfolder_dir $runfolder_path --bustard_dir $bustard_rta --run 1234 --lane 4 --t_filter 2 --read 1 --cstart 1 --prefix 1234_4_1 --mode 2 --bam 1234_4.bam "};

  is( $harold->_calibration_table_bsub_command( {
   dir => $bustard_rta,
   position => 4,
   read => 1,
   job_dependencies => $req_job_completion,
   ref_seq => q{phix-illumina.fa},
   control => 1,
  } ), $job, q{generated cal_table control bsub command is correct} );

  lives_ok {
    @job_ids = $harold->generate_calibration_table( $arg_refs );
  } q{no croak submitting calibration table jobs};
  is( scalar @job_ids, 2, q{2 jobs created} );
  $job = qq{bsub -q test -o log/PB_cal_score_1234_4_20091028-101635.out -J PB_cal_score_1234_4_20091028-101635 -C 99999999 -R 'select[mem>1725] rusage[mem=1725,nfs_12=1] span[hosts=1]' -M 1725000 -w'done(123) && done(321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_predictor --runfolder_dir /staging/IL2/analysis/123456_IL2_1234 --bustard_dir /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA --run 1234 --lane 4 --read 1 --ct 1234_4_1_train_purity_cycle_caltable.txt --cstart 1 "};

  is( $util->drop_temp_part_from_paths( $harold->_recalibration_bsub_command( {
    dir => $bustard_rta,
    position => 4,
    read => 1,
    job_dependencies => $req_job_completion,
    calibration_table => q{1234_4_1_train_purity_cycle_caltable.txt},
  } ) ), $job, q{generated recalibration control bsub command is correct} );

  lives_ok {
    @job_ids = $harold->generate_recalibrated_qseqs( $arg_refs );
  } q{no croak submitting recalibration jobs};
  is( scalar @job_ids, 8, q{8 jobs created - all using control lane caltable} );

}

{
  set_staging_analysis_area();
  my $harold;
  $id_run = 4846;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => $id_run,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      no_control_lane => 1,
      verbose => 1,
      conf_path => $conf_path,
      domain => q{test},
      ref_repository => $curdir . q{/t/data/sequence/references},
      instrument_model => q{HK},
    });
  } q{create $harold object ok};
  $refs = [];
  isa_ok($harold, q{npg_pipeline::analysis::harold_calibration}, q{$harold});
  my @job_ids = $harold->generate_calibration_table({});
  is( scalar @job_ids, 0, q{no job ids as no_control_lane set and no references found} );
  $refs = [ qw{ test with more than one ref returned } ];
  @job_ids = $harold->generate_calibration_table({});
  is( scalar @job_ids, 0, q{no job ids as no_control_lane set, and multiple references found} );
  @job_ids = $harold->generate_recalibrated_qseqs({});
  is( scalar @job_ids, 0, q{no job ids as no_control_lane set, and no single reference able to be returned} );

  $single_ref_found = 1;
  $refs = [ q{/path/to/references/fasta.fa} ];

  @job_ids = $harold->generate_calibration_table({});
  is( scalar @job_ids, 8, q{8 job ids as no_control_lane set, and single references found} );


  @job_ids = $harold->generate_recalibrated_qseqs({});
  is( scalar @job_ids, 8, q{8 job ids as no_control_lane set, so lanes own cal tables used} );

}

{
  set_staging_analysis_area();
  my $harold;
  $id_run = 1234;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => $id_run,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      verbose => 1,
      conf_path => $conf_path,
      domain => q{test},
      ref_repository => $curdir . q{/t/data/sequence/references},
      instrument_model => q{HK},

    });
  } q{create $harold object ok};

  my @job_ids = $harold->generate_calibration_table({});
  is( scalar @job_ids, 8, q{8 job ids as no_control_lane set, and single references found} );


  @job_ids = $harold->generate_recalibrated_qseqs({});
  is( scalar @job_ids, 8, q{8 job ids as no_control_lane set, so lanes own cal tables used} );

  my $arg_refs = {
    timestamp => q{20091028-101635},
    position => 1,
    job_dependencies => q{-w 'done(1234) && done(4321)'},
    ref_seq => q{t/data/sequence/references/Human/default/all/bwa/someref.fa.bwt},
  };

  my $single_read_alignment_command = q{bsub -q test -E 't/bin/software/solexa/bin/npg_pipeline_preexec_references --ref_repository t/data/sequence/references' -o log/PB_cal_align_1234_1_20091028-101635.out -J PB_cal_align_1234_1_20091028-101635 -C 99999999 -R 'select[mem>8000] rusage[mem=8000,nfs_12=1] span[hosts=1]' -M 8000000 -w 'done(1234) && done(4321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_align --run 1234 --lane 1 --random 5 --runfolder_dir /staging/IL2/analysis/123456_IL2_1234 --bustard_dir /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --ref t/data/sequence/references/Human/default/all/bwa/someref.fa.bwt --rta --read 1 --pf_filter "};
  my $paired_read_alignment_command = q{bsub -q test -E 't/bin/software/solexa/bin/npg_pipeline_preexec_references --ref_repository t/data/sequence/references' -o log/PB_cal_align_1234_1_20091028-101635.out -J PB_cal_align_1234_1_20091028-101635 -C 99999999 -R 'select[mem>8000] rusage[mem=8000,nfs_12=1] span[hosts=1]' -M 8000000 -w 'done(1234) && done(4321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_align --run 1234 --lane 1 --random 5 --runfolder_dir /staging/IL2/analysis/123456_IL2_1234 --bustard_dir /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --ref t/data/sequence/references/Human/default/all/bwa/someref.fa.bwt --rta --read1 1 --read2 2 --pf_filter "};
  my $spiked_read_alignment_command = q{bsub -q test -E 't/bin/software/solexa/bin/npg_pipeline_preexec_references --ref_repository t/data/sequence/references' -o log/PB_cal_align_1234_1_20091028-101635.out -J PB_cal_align_1234_1_20091028-101635 -C 99999999 -R 'select[mem>8000] rusage[mem=8000,nfs_12=1] span[hosts=1]' -M 8000000 -w 'done(1234) && done(4321)' " t/bin/software/solexa/src/new-pipeline-dev/pb_calibration/branches/prerelease-6.0/bin/pb_align --run 1234 --lane 1 --runfolder_dir /staging/IL2/analysis/123456_IL2_1234 --bustard_dir /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --ref t/data/sequence/references/PhiX/default/all/fasta/phix-illumina.fa --rta --read1 1 --read2 2 --pf_filter "};

  is( $util->drop_temp_part_from_paths( $harold->_alignment_file_bsub_command( $arg_refs ) ), $single_read_alignment_command, q{single read alignment bsub command is correct} );

  $arg_refs->{is_paired} = 1;
  is( $util->drop_temp_part_from_paths( $harold->_alignment_file_bsub_command( $arg_refs ) ), $paired_read_alignment_command, q{paired read alignment bsub command is correct} );

  $arg_refs->{is_spiked_phix} = 1;
  $arg_refs->{ref_seq} = q{t/data/sequence/references/PhiX/default/all/fasta/phix-illumina.fa};
  is( $util->drop_temp_part_from_paths( $harold->_alignment_file_bsub_command( $arg_refs ) ), $spiked_read_alignment_command, q{paired read alignment bsub command is correct} );

  @job_ids = $harold->generate_alignment_files({});
  is( scalar @job_ids, 8, q{8 job ids, no_control_lane set} );

}

{
  set_staging_analysis_area();
  my $harold;
  $id_run = 1234;
  lives_ok {
    $harold = npg_pipeline::analysis::harold_calibration->new({
      id_run => $id_run,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      verbose => 1,
      conf_path => $conf_path,
      domain => q{test},
      no_munge_summary => 1,
      no_summary_link => 1,
      no_recalibration => 1,
      no_status_updates => 1,
      log_file_path => $runfolder_path,
      log_file_name => q{npg_pipeline_pb_cal_20091028-101635.log},
      ref_repository => $curdir . q{/t/data/sequence/references},
      instrument_model => q{HiSeq},
    });
  } q{create $harold object ok};

  is( $util->drop_temp_part_from_paths( $harold->_post_qseq_cmd({
    required_job_dependencies => q{-w'done(123) & done(321)'},
  }) ), q{bsub -q test  -R 'rusage[nfs_12=1]' -o '/staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal/log/post_qseq_1234_20091028-101635-%J.out' -J post_qseq_1234_20091028-101635 't/bin/software/solexa/bin/npg_pipeline_post_qseq --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --id_run 1234 --instrument_model HiSeq --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --lsf_queue test --no_munge_summary  --no_recalibration  --no_status_updates  --no_summary_link  --pb_cal_log_file /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_pb_cal_20091028-101635.log --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --ref_repository t/data/sequence/references --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234 --tag_qseqs_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal/tag_qseqs --verbose '},
  q{generated post_qseq bsub command is correct} );

  note $harold->_bcl_pipeline();
}



1;
